Changes
=======

0.1.6 - 2018-03-21
------------------
* Updated docs and provide an additional zip file


0.1.5 - 2018-03-13
------------------
* Updated Segno to version 0.2.7
* Fixed #1 "Support for Structured Append"
* Fixed #2 (avoid exceptions if a Micro QR Code is chosen)


0.1.4 - 2017-01-31
------------------
* Updated Segno version to 0.2.4 to avoid problems with Micro QR Codes


0.1.3 - 2016-09-15
------------------
* Fixed inkscape_qrcode.inx (pointed to a wrong path)
* Fixed Python packaging


0.1.2 - 2016-09-15
------------------
* Updated underlying Segno version to 0.2.0 since
  the previous version may create invalid QR Codes if "error boost" is
  enabled


0.1.1 - 2016-09-07
------------------
* Initial release
